SnbtErrorKind

Enum SnbtErrorKind 

#[non_exhaustive]
pub enum SnbtErrorKind {
Show 33 variants TrailingData, ExpectedSymbol(char), ExpectedValue, ExpectedKey, EmptyKey, ExpectedArrayElement, InvalidArrayElementType, ExpectedNumberOrBoolean, ExpectedStringUuid, UnknownOperation { name: String, argument_count: usize, }, ExpectedNumber, ExpectedBinaryNumeral, ExpectedDecimalNumeral, ExpectedHexNumeral, ExpectedQuotedString, UnclosedQuotedString, UnclosedEscapeSequence, InvalidEscape(char), ExpectedHexEscape { digits: usize, }, InvalidCodepoint(u32), ExpectedCharacterName, UnclosedCharacterName, InvalidCharacterName(String), ExpectedUnquotedString, InvalidFloatingPoint, NonFiniteNumber, InvalidUnderscore, InvalidInteger, LeadingZero, ExpectedNonNegativeNumber, IntegerTooLarge, NumberOutOfRange { number_type: SnbtNumberType, unsigned: bool, }, InvalidNumber,
}
Specific reason why SNBT parsing failed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TrailingData

Non-whitespace input remained after a complete tag.



ExpectedSymbol(char)

A grammar symbol was required at the cursor.



ExpectedValue

An SNBT value was required at the cursor.



ExpectedKey

A compound key was required at the cursor.



EmptyKey

A compound key was present but empty.



ExpectedArrayElement

A typed-array element was not an integer.



InvalidArrayElementType

A typed-array element used an unsupported integer width.



ExpectedNumberOrBoolean

The bool operation received neither a number nor a boolean.



ExpectedStringUuid

The uuid operation did not receive a valid UUID string.



UnknownOperation

No built-in operation matched the name and argument count.

Fields

name: String

Operation name supplied by the input.

argument_count: usize

Number of supplied arguments.



ExpectedNumber

A number was required at the cursor.



ExpectedBinaryNumeral

A binary numeral was required at the cursor.



ExpectedDecimalNumeral

A decimal numeral was required at the cursor.



ExpectedHexNumeral

A hexadecimal numeral was required at the cursor.



ExpectedQuotedString

A quoted string was required at the cursor.



UnclosedQuotedString

A quoted string was not terminated.



UnclosedEscapeSequence

An escape introducer was not followed by an escape value.



InvalidEscape(char)

A quoted string contained an unsupported escape.



ExpectedHexEscape

A Unicode escape did not contain the required hexadecimal digits.

Fields

digits: usize

Required number of hexadecimal digits.



InvalidCodepoint(u32)

A Unicode escape resolved to an invalid code point.



ExpectedCharacterName

A named Unicode escape did not begin with a character name.



UnclosedCharacterName

A named Unicode escape was not terminated.



InvalidCharacterName(String)

A named Unicode escape did not identify a character.



ExpectedUnquotedString

An unquoted string was required at the cursor.



InvalidFloatingPoint

A floating-point token could not be parsed.



NonFiniteNumber

A non-finite floating-point value was supplied.



InvalidUnderscore

A number placed underscores outside its digits.



InvalidInteger

An integer token could not be parsed.



LeadingZero

A decimal integer contained a leading zero.



ExpectedNonNegativeNumber

An unsigned integer was negative.



IntegerTooLarge

An integer exceeded the parser’s intermediate representation.



NumberOutOfRange

A number did not fit its requested NBT integer type.

Fields

number_type: SnbtNumberType

Requested NBT integer type.

unsigned: bool

Whether the literal requested the unsigned range.



InvalidNumber

A number token did not contain any digits.

Implementations

Source

impl SnbtErrorKind

pub fn component(&self) -> TextComponent

Returns this failure as a translatable text component.